==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/costexplorer/kotlin/inputs/CostCategoryRuleRuleNotTagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.costexplorer.kotlin.inputs

import com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property key Key for the tag.
 * @property matchOptions Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
 * @property values Specific value of the Cost Category.
 */
public data class CostCategoryRuleRuleNotTagsArgs(
    public val key: Output<String>? = null,
    public val matchOptions: Output<List<String>>? = null,
    public val values: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs> {
    override fun toJava(): com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs =
        com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .matchOptions(matchOptions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .values(values?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CostCategoryRuleRuleNotTagsArgs].
 */
@PulumiTagMarker
public class CostCategoryRuleRuleNotTagsArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var matchOptions: Output<List<String>>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Key for the tag.
     */
    @JvmName("dymudnpekktrobct")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("emkkkgkldlujhyho")
    public suspend fun matchOptions(`value`: Output<List<String>>) {
        this.matchOptions = value
    }

    @JvmName("tewsovcsllpogwbf")
    public suspend fun matchOptions(vararg values: Output<String>) {
        this.matchOptions = Output.all(values.asList())
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("jqyfkmltroadolsw")
    public suspend fun matchOptions(values: List<Output<String>>) {
        this.matchOptions = Output.all(values)
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("nmdxadbgqmadntyb")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("qymskycmrvvwnmkj")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("gqamdmsrfmlqtnbw")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Key for the tag.
     */
    @JvmName("isfbkajxlfrpvvxw")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("wavtlwyedabjuokx")
    public suspend fun matchOptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchOptions = mapped
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("hbowkxlystayvqis")
    public suspend fun matchOptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchOptions = mapped
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("meacuwgdrakhorxa")
    public suspend fun values(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("gxnnirrghljidgop")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): CostCategoryRuleRuleNotTagsArgs = CostCategoryRuleRuleNotTagsArgs(
        key = key,
        matchOptions = matchOptions,
        values = values,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/costexplorer/kotlin/inputs/CostCategoryRuleRuleNotTagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.costexplorer.kotlin.inputs

import com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property key Key for the tag.
 * @property matchOptions Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
 * @property values Specific value of the Cost Category.
 */
public data class CostCategoryRuleRuleNotTagsArgs(
    public val key: Output<String>? = null,
    public val matchOptions: Output<List<String>>? = null,
    public val values: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs> {
    override fun toJava(): com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs =
        com.pulumi.aws.costexplorer.inputs.CostCategoryRuleRuleNotTagsArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .matchOptions(matchOptions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .values(values?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [CostCategoryRuleRuleNotTagsArgs].
 */
@PulumiTagMarker
public class CostCategoryRuleRuleNotTagsArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var matchOptions: Output<List<String>>? = null

    private var values: Output<List<String>>? = null

    /**
     * @param value Key for the tag.
     */
    @JvmName("dlwmvgwyjphphxwd")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("mqnmmuisrhrysqgv")
    public suspend fun matchOptions(`value`: Output<List<String>>) {
        this.matchOptions = value
    }

    @JvmName("ayjdhraowbntkfok")
    public suspend fun matchOptions(vararg values: Output<String>) {
        this.matchOptions = Output.all(values.asList())
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("wswvujtkpqstjqva")
    public suspend fun matchOptions(values: List<Output<String>>) {
        this.matchOptions = Output.all(values)
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("mwoysvdsbrgxdkgo")
    public suspend fun values(`value`: Output<List<String>>) {
        this.values = value
    }

    @JvmName("mnyfhhhqclocguiu")
    public suspend fun values(vararg values: Output<String>) {
        this.values = Output.all(values.asList())
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("itltqqmaqxtxpxpw")
    public suspend fun values(values: List<Output<String>>) {
        this.values = Output.all(values)
    }

    /**
     * @param value Key for the tag.
     */
    @JvmName("rewevitydheawcoa")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("qwtytwkipxbxbhov")
    public suspend fun matchOptions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.matchOptions = mapped
    }

    /**
     * @param values Match options that you can use to filter your results. MatchOptions is only applicable for actions related to cost category. The default values for MatchOptions is `EQUALS` and `CASE_SENSITIVE`. Valid values are: `EQUALS`,  `ABSENT`, `STARTS_WITH`, `ENDS_WITH`, `CONTAINS`, `CASE_SENSITIVE`, `CASE_INSENSITIVE`.
     */
    @JvmName("jjnlbcxetuprrwaq")
    public suspend fun matchOptions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.matchOptions = mapped
    }

    /**
     * @param value Specific value of the Cost Category.
     */
    @JvmName("wqoiakxkjbnocwwo")
    public suspend fun values(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.values = mapped
    }

    /**
     * @param values Specific value of the Cost Category.
     */
    @JvmName("afwlekojsnvvssrf")
    public suspend fun values(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.values = mapped
    }

    internal fun build(): CostCategoryRuleRuleNotTagsArgs = CostCategoryRuleRuleNotTagsArgs(
        key = key,
        matchOptions = matchOptions,
        values = values,
    )
}
